@@ -14,6 +14,9 @@ from satnogsdbapiclient.model.iaru_coordination_enum import IaruCoordinationEnum
 from satnogsdbapiclient.model.latest_tle_set import LatestTleSet
 from satnogsdbapiclient.model.mode import Mode
 from satnogsdbapiclient.model.new_artifact import NewArtifact
+from satnogsdbapiclient.model.optical_identification import OpticalIdentification
+from satnogsdbapiclient.model.optical_observation import OpticalObservation
+from satnogsdbapiclient.model.optical_observation_create import OpticalObservationCreate
 from satnogsdbapiclient.model.paginated_artifact_list import PaginatedArtifactList
 from satnogsdbapiclient.model.paginated_telemetry_list import PaginatedTelemetryList
 from satnogsdbapiclient.model.satellite import Satellite
